Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(562)

Unified Diff: content/browser/frame_host/navigator_impl.cc

Issue 2483703002: Replicate feature policy headers to remote frames (Closed)
Patch Set: Addressing review comments Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/frame_host/frame_tree_node.cc ('k') | content/browser/frame_host/render_frame_host_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/navigator_impl.cc
diff --git a/content/browser/frame_host/navigator_impl.cc b/content/browser/frame_host/navigator_impl.cc
index 71063d8c46ba485a3eb2756f9ecb588f9f908940..5adba8d0796f05b27d99a1473f84b0e4f3a85b69 100644
--- a/content/browser/frame_host/navigator_impl.cc
+++ b/content/browser/frame_host/navigator_impl.cc
@@ -582,9 +582,11 @@ void NavigatorImpl::DidNavigate(
params.insecure_request_policy);
// Navigating to a new location means a new, fresh set of http headers and/or
- // <meta> elements - we need to reset CSP policy to an empty set.
- if (!is_navigation_within_page)
+ // <meta> elements - we need to reset CSP and Feature Policy.
+ if (!is_navigation_within_page) {
render_frame_host->frame_tree_node()->ResetContentSecurityPolicy();
+ render_frame_host->frame_tree_node()->ResetFeaturePolicy();
+ }
// When using --site-per-process, we notify the RFHM for all navigations,
// not just main frame navigations.
« no previous file with comments | « content/browser/frame_host/frame_tree_node.cc ('k') | content/browser/frame_host/render_frame_host_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698